@@ -300,6 +300,25 @@ marshal_int__string_string_string_string_int (void *func, json_t *param_array, g
 }
 
 
+static char *
+marshal_int__string_string_string_string_string_int (void *func, json_t *param_array, gsize *ret_len)
+{
+    GError *error = NULL;
+    const char* param1 = json_array_get_string_or_null_element (param_array, 1);
+    const char* param2 = json_array_get_string_or_null_element (param_array, 2);
+    const char* param3 = json_array_get_string_or_null_element (param_array, 3);
+    const char* param4 = json_array_get_string_or_null_element (param_array, 4);
+    const char* param5 = json_array_get_string_or_null_element (param_array, 5);
+    int param6 = json_array_get_int_element (param_array, 6);
+
+    int ret = ((int (*)(const char*, const char*, const char*, const char*, const char*, int, GError **))func) (param1, param2, param3, param4, param5, param6, &error);
+
+    json_t *object = json_object ();
+    searpc_set_int_to_ret_object (object, ret);
+    return searpc_marshal_set_ret_common (object, ret_len, error);
+}
+
+
 static char *
 marshal_int__string_string_int_int (void *func, json_t *param_array, gsize *ret_len)
 {
@@ -1466,7 +1485,21 @@ marshal_json__void (void *func, json_t *param_array, gsize *ret_len)
     return searpc_marshal_set_ret_common (object, ret_len, error);
 }
 
-static void register_marshals()
+
+static char *
+marshal_json__string (void *func, json_t *param_array, gsize *ret_len)
+{
+    GError *error = NULL;
+    const char* param1 = json_array_get_string_or_null_element (param_array, 1);
+
+    json_t* ret = ((json_t* (*)(const char*, GError **))func) (param1, &error);
+
+    json_t *object = json_object ();
+    searpc_set_json_to_ret_object (object, ret);
+    return searpc_marshal_set_ret_common (object, ret_len, error);
+}
+
+static void register_marshals(void)
 {
 
     {
@@ -1564,6 +1597,11 @@ static void register_marshals()
     }
 
 
+    {
+        searpc_server_register_marshal (searpc_signature_int__string_string_string_string_string_int(), marshal_int__string_string_string_string_string_int);
+    }
+
+
     {
         searpc_server_register_marshal (searpc_signature_int__string_string_int_int(), marshal_int__string_string_int_int);
     }
@@ -1913,4 +1951,9 @@ static void register_marshals()
         searpc_server_register_marshal (searpc_signature_json__void(), marshal_json__void);
     }
 
+
+    {
+        searpc_server_register_marshal (searpc_signature_json__string(), marshal_json__string);
+    }
+
 }
